@@ -54,9 +54,15 @@ void PhonedevPlay::Initial(void)
 	struct tm *dt;
 	struct tm tbuf;
 	char *ann;
+	int ctrl;
 	
 	trunk->getName(buffer);
+#ifdef	POSIX_PHONEDEV
+	ctrl = data->play.volume * 10;
+	ioctl(dev, PHONE_PLAY_VOLUME, &ctrl);
+#else
 	ioctl(dev, PHONE_PLAY_VOLUME, data->play.volume * 10);
+#endif
 	stat(fn, &ino);
 	Open(fn);	
 	if(!isOpen())
@@ -91,7 +97,12 @@ void PhonedevPlay::Initial(void)
 	}
 
 	reset = true;
+#ifdef	POSIX_PHONEDEV
+	ctrl = phivr.getAudioBuffers();
+	ioctl(dev, PHONE_PLAY_DEPTH, &ctrl);
+#else
 	ioctl(dev, PHONE_PLAY_DEPTH, phivr.getAudioBuffers());
+#endif
 
 	switch(driver)
 	{
@@ -103,8 +114,21 @@ void PhonedevPlay::Initial(void)
 #endif
 	}
 
+#ifdef	POSIX_PHONEDEV
+	for(;;)
+	{
+		ctrl = framing;
+		ioctl(dev, PHONE_FRAME, &ctrl);
+		if(framing == ctrl)
+			break;
+		if(++count > 4)
+			break;
+		Sleep(20);
+	}
+#else
 	while(framing != ioctl(dev, PHONE_FRAME, framing) && count++ < 5)
 		Sleep(20);
+#endif
 
 	if(count > 4)
 	{
@@ -112,7 +136,11 @@ void PhonedevPlay::Initial(void)
  		Failure();
 	}
 
+#ifdef	POSIX_PHONEDEV
+	if(ioctl(dev, PHONE_PLAY_CODEC, &codec))
+#else
 	if(ioctl(dev, PHONE_PLAY_CODEC, codec))
+#endif
 	{
 		slog(SLOG_ERROR) << buffer << ": cannot set codec" << endl;
 		Failure();
