@@ -20,6 +20,7 @@
 PhonedevRecord::PhonedevRecord(PhonedevTrunk *trunk) :
 Service((Trunk *)trunk, keythreads.priAudio()), AudioFile()
 {
+	stopped = false;
 	reset = false;
 	driver = trunk->getDriver();
 	dev = trunk->getDevice();
@@ -53,6 +54,7 @@ void PhonedevRecord::Initial(void)
 	char buffer[32];
 	audioinfo_t info;
 	char *ext = strrchr(data->record.name, '.');
+	int ctrl;
 
 	trunk->getName(buffer);
 	info.format = AUDIO_FORMAT_RAW;
@@ -77,7 +79,12 @@ void PhonedevRecord::Initial(void)
 		info.order = __LITTLE_ENDIAN;
 	}
 
+#ifdef	POSIX_PHONEDEV
+	ctrl = data->record.volume * 10;
+	ioctl(dev, PHONE_REC_VOLUME, &ctrl);
+#else
 	ioctl(dev, PHONE_REC_VOLUME, data->record.volume * 10);
+#endif
 	if(data->record.append)
 		Open(data->record.name);
 	else
@@ -107,7 +114,12 @@ void PhonedevRecord::Initial(void)
 	}
 
 	reset = true;
+#ifdef	POSIX_PHONEDEV
+	ctrl = phivr.getAudioBuffers();
+	ioctl(dev, PHONE_REC_DEPTH, &ctrl);
+#else
 	ioctl(dev, PHONE_REC_DEPTH, phivr.getAudioBuffers());
+#endif
 
 	switch(driver)
 	{
@@ -119,8 +131,21 @@ void PhonedevRecord::Initial(void)
 #endif
 	}
 
+#ifdef	POSIX_PHONEDEV
+	for(;;)
+	{
+		ctrl = framing;
+		ioctl(dev, PHONE_FRAME, &ctrl);
+		if(framing == ctrl)
+			break;
+		if(++count > 4)
+			break;
+		Sleep(20);
+	}
+#else
 	while(framing != ioctl(dev, PHONE_FRAME, framing) && count++ < 5)
 		Sleep(20);
+#endif
 
 	if(count > 4)
 	{
@@ -128,7 +153,11 @@ void PhonedevRecord::Initial(void)
  		Failure();
 	}
 
+#ifdef	POSIX_PHONEDEV
+	if(ioctl(dev, PHONE_REC_CODEC, &codec))
+#else
 	if(ioctl(dev, PHONE_REC_CODEC, codec))
+#endif
 	{
 		slog(SLOG_ERROR) << buffer << ": cannot set codec" << endl;
 		Failure();
