@@ -46,11 +46,13 @@
 bool PikaTrunk::answerHandler(TrunkEvent *event)
 {
 	timeout_t wakeup;
-
+	
 	switch(event->id)
 	{
-	case TRUNK_STOP_DISCONNECT:
 	case TRUNK_LINE_WINK:
+		if(!flags.offhook)
+			return true;
+	case TRUNK_STOP_DISCONNECT:
 	case TRUNK_CPA_DIALTONE:
 	case TRUNK_TIMER_EXPIRED:
 		stopDSP();
@@ -75,6 +77,7 @@ bool PikaTrunk::answerHandler(TrunkEvent *event)
 			setTimer(data.answer.timeout);
 			return true;
 		}
+		endTimer();
 		stopDSP();
 		PK_TRUNK_OffHook(hTrk);
 		flags.offhook = true;
