@@ -47,6 +47,7 @@
 PikaRecord::PikaRecord(PikaTrunk *trunk) :
 Service((Trunk *)trunk, keythreads.priAudio()), AudioFile()
 {
+	stopped = false;
 	reset = false;
 	hDsp = trunk->getDevice();
 	clrAudio();
@@ -300,6 +301,7 @@ bool PikaTrunk::recordHandler(TrunkEvent *event)
 		status[id] = 'r';
 		if(!flags.offhook)
 		{
+			flags.offhook = true;
 			PK_TRUNK_OffHook(hTrk);
 			return true;
 		}
