@@ -88,6 +88,8 @@ PikaTrunk::~PikaTrunk()
 
 void PikaTrunk::getCIDResource(void)
 {
+	int rtn;
+
 	if(flags.dsp != DSP_MODE_INACTIVE)
 		return;
 
@@ -98,6 +100,7 @@ void PikaTrunk::getCIDResource(void)
 	if(!hDsp)
 		return;
 
+
 	if(PK_MVIP_FullDuplexConnect(hTrk, hDsp))
 	{
 		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id << ": cannot connect cid resource" << endl;
@@ -105,7 +108,7 @@ void PikaTrunk::getCIDResource(void)
 	}
 	PK_DSP_SetEventHandler(hDsp, id, (pikacall_t)&PikaTrunk::callback);
 
-	PK_CID_SetBuffer(hDsp, cidbuf, PK_CID_BUFFER_SIZE);
+	rtn = PK_CID_SetBuffer(hDsp, cidbuf, PK_CID_BUFFER_SIZE);
 	PK_CID_SetTimeOut(hDsp, PK_CID_DEFAULT_TIME_OUT);	
 	if(PK_CID_Enable(hDsp))
 		slog(SLOG_DEBUG) << pikaivr.getCardName(card) << id << ": cannot activate callerid" << endl;
@@ -208,6 +211,9 @@ void PikaTrunk::getName(char *buffer)
 
 void PikaTrunk::Exit(void)
 {
+	char buffer[33];
+	getName(buffer);
+	slog(SLOG_DEBUG) << buffer << ": script exiting" << endl;
 	handler = &PikaTrunk::hangupHandler;
 }
 
@@ -291,10 +297,12 @@ retry:
 			setDTMFDetect(false);
 		endTimer();
 		break;
+	case TRUNK_LINE_WINK:
+		if(!flags.offhook)
+			break;
 	case TRUNK_STOP_DISCONNECT:
 	case TRUNK_CPA_DIALTONE:
-	case TRUNK_LINE_WINK:
-		slog(SLOG_DEBUG) << pikaivr.getCardName(card) << id << ": disconnect" << endl;
+		slog(SLOG_DEBUG) << pikaivr.getCardName(card) << id << ": disconnecting" << endl;
 		TrunkSignal(TRUNK_SIGNAL_HANGUP);
 		event->id = TRUNK_STOP_STATE;
 		goto retry;
