@@ -29,6 +29,16 @@ Keydata("/bayonne/vpb")
 	Load(defkeys);
 }
 
+size_t VPBConfig::getStack(void)
+{
+	const char *cp = getLast("stack");
+
+	if(!cp)
+		return keythreads.getStack();
+
+	return atoi(cp) * 1024;
+}
+
 VPBDriver::VPBDriver() :
 Driver()
 {
