@@ -31,6 +31,7 @@ bool VPBTrunk::idleHandler(TrunkEvent *event)
 	case TRUNK_ENTER_STATE:
 		debug->DebugState(this, "idle");
 		tgi.pid = 0;
+		digits = 0;
 
 		vpb_sethook_async(handle, VPB_ONHOOK);
 		setDTMFDetect(false);
@@ -89,7 +90,7 @@ bool VPBTrunk::idleHandler(TrunkEvent *event)
 			}		
 			if(flags.trunk == TRUNK_MODE_OUTGOING)
 			{
-//				handler = &VPBTrunk::seizeHandler;
+				handler = &VPBTrunk::seizeHandler;
 				group->incOutgoing();
 			}
 			else
