@@ -21,6 +21,7 @@ Service((Trunk *)trunk, keythreads.priAudio()), AudioFile()
 {
 	handle = h;
 	reset = false;
+	stopped = false;
 }
 
 VPBRecord::~VPBRecord()
@@ -173,6 +174,7 @@ bool VPBTrunk::recordHandler(TrunkEvent *event)
 		status[id] = 'r';
 		if(!flags.offhook)
 		{
+			flags.offhook = true;
 			vpb_sethook_async(handle, VPB_OFFHOOK);
 			setTimer(vpbivr.getHookTimer());
 			return true;
