@@ -74,7 +74,7 @@ SMTPSession::~SMTPSession()
 {
 	Terminate();
 	(smtp->getSessions())->Post();
-	delete header;
+	delete[] header;
 }
 
 InetHostAddress &SMTPSession::getPeer(Protocol *pro)
