@@ -35,6 +35,13 @@
 
 #include <stdlib.h>
 
+#ifdef	__FreeBSD__
+#undef	read
+#undef	write
+#undef	readv
+#undef	writev
+#endif
+
 #ifndef	COMMON_TPPORT_TYPE_DEFINED
 typedef	short	tpport_t;
 #endif
@@ -719,6 +726,31 @@ public:
 		{return atoi(getLast("page"));};
 };
 
+/**
+ * Load /etc/bayonne [audiofeed] key value pairs.  This is used to
+ * configure audio feed sources for Bayonne.
+ *
+ * @author David Sugar <dyfet@ostel.com>
+ * @short Audio feed related options.
+ */
+class KeyFeed : public Keydata
+{
+public:
+	/**
+	 * Initialize keymemory data.
+	 */
+	KeyFeed();
+
+	/**
+	 * Get number of 120ms audio buffers to use.
+	 *
+	 * @return number of bytes of storage for new symbols.
+	 */
+	inline unsigned getBuffers(void)
+		{return atoi(getLast("buffers"));};
+};
+
+
 /**
  * Load /etc/bayonne [thread] key value pairs.  Has internal defaults
  * if section or file is missing.
@@ -774,6 +806,13 @@ public:
 	inline int getResetDelay(void)
 		{return atoi(getLast("resetdelay"));};
 
+	/**
+	 * Get default stack size for threads.
+	 *
+	 * @return stack size in "k" increments.
+	 */
+	size_t getStack(void);
+
 	/**
 	 * Get count of service pool threads to use.
 	 *
@@ -804,6 +843,14 @@ public:
 	inline int priAudio(void)
 		{return atoi(getLast("audio"));};
 
+	/**
+	 * Get relative priority to run audio feeds at.
+	 *
+	 * @return audio feed priority (relative).
+	 */
+	inline int priFeed(void)
+		{return atoi(getLast("feed"));};
+
 	/**
 	 * Get relative priority to run gateway (TGI) sessions at.
 	 *
@@ -1131,10 +1178,15 @@ public:
 	void loadFunctions(void);
 
 	/**
-	 * Attemot to load DSO based protocol modules into the server.
+	 * Attempt to load DSO based protocol modules into the server.
 	 */
 	void loadModules(void);
 
+	/**
+	 * Attempt to load DSO based audio feed modules into the server.
+	 */
+	void loadFeeds(void);
+
 	/**
 	 * Attempt to load TGI based resident interpreters.
 	 */
@@ -2428,6 +2480,7 @@ extern KeyPaths keypaths;
 extern KeyLocal keylocal;
 extern KeyMailbox keymailbox;
 extern KeyTones keytones;
+extern KeyFeed keyfeed;
 extern Plugins plugins;
 extern Driver *driver;
 extern StatMon *statmon;
