@@ -50,6 +50,21 @@ Keydata("/bayonne/paths")
 	Load(defpaths);
 }
 
+KeyFeed::KeyFeed() :
+Keydata("/bayonne/audiofeed")
+{
+	static KEYDEF defkeys[] = {
+	{"buffers", "4"},
+	{"format", "ulaw"},
+#ifdef	__FreeBSD__
+	{"stack", "2"},
+#endif
+	{NULL, NULL}};
+
+	Load("~bayonne/audiofeeds");
+	Load(defkeys);
+}
+
 KeyServer::KeyServer() :
 Keydata("/bayonne/server")
 {
@@ -133,6 +148,7 @@ Keydata("/bayonne/threads")
 {
 	static KEYDEF defpaths[] = {
 	{"audio", "0"},
+	{"feed", "0"},
 	{"priority", "0"},
 	{"gateways", "0,1"},
 	{"services", "1,1"},
@@ -146,6 +162,9 @@ Keydata("/bayonne/threads")
 	{"refresh", "5"},
 	{"policy", "other"},
 	{"pages", "0"},
+#ifdef	__FreeBSD__
+	{"stack", "8"},
+#endif
 	{NULL, NULL}};
 
 	const char *cp = getLast("pri");
@@ -197,6 +216,16 @@ Keydata("/bayonne/memory")
 	Load(defpaths);
 }
 
+size_t KeyThreads::getStack(void)
+{
+	const char *cp = getLast("stack");
+
+	if(cp)
+		return atoi(cp) * 1024;
+	
+	return 0;
+}
+
 int KeyThreads::priResolver(void)
 {
 	const char *cp = getLast("resolver");
@@ -442,6 +471,39 @@ void Plugins::loadModules(void)
 	}
 }
 
+
+void Plugins::loadFeeds(void)
+{
+	char path[256];
+	char list[512];
+	char *cp;
+
+	cp = (char *)getLast("feeds");
+	if(!cp)
+		return;
+
+	strcpy(list, cp);
+	cp = strtok(list, " \t\n;,");
+	while(cp)
+	{
+		if(!*cp)
+			break;
+
+		if(*cp == '/')
+			path[0] = 0;
+		else
+		{
+			strcpy(path, keypaths.getLibpath());
+			strcat(path, LIB_VERSION);
+		}
+		strcat(path, cp);
+		if(*cp != '/')
+			strcat(path, ".feed");
+		new DSO(path);
+		cp = strtok(NULL, " \t\n;,");
+	}
+}
+
 void Plugins::loadTGI(void)
 {
 	char path[256];
@@ -628,7 +690,7 @@ Keydata("/bayonne/trunks"), CallStat()
 	KEYDEF keys[] = {
 		{"answer", "1"},
 		{"hangup", "100"},
-		{"ringtime", "6"},
+		{"ringtime", "7"},
 		{"flash", "200"},
 		{"dialtone", "800"},
 		{"dialspeed", "160"},
@@ -832,6 +894,7 @@ KeyMailbox keymailbox;
 KeyTones keytones;
 KeyThreads keythreads;
 KeyMemory keymemory;
+KeyFeed keyfeed;
 Plugins plugins;
 Scheduler scheduler;
 
