@@ -196,7 +196,7 @@ Database::Database()
 }
 
 Server::Server(int pri) :
-Thread(NULL, pri)
+Thread(NULL, pri, keythreads.getStack())
 {
 	next = first;
 	first = this;
