@@ -96,7 +96,11 @@ static void tgi(void)
 
 	for(pool = 0; pool < count; ++ pool)
 	{
+#ifdef	__FreeBSD__
+		tgipids[pool] = vfork();
+#else
 		tgipids[pool] = fork();
+#endif
 		if(!tgipids[pool])
 			break;
 	}
@@ -148,10 +152,14 @@ static void tgi(void)
 				write(cfd, buffer, strlen(buffer));
 			}
 
+#ifdef	__FreeBSD__
+			wait4(vpid, &stat, 0, NULL);
+#else
 			waitpid(vpid, &stat, 0);
+#endif
 			if(!cmd.detach)
 			{
-				sprintf(buffer, "exit %d %d", cmd.port, WEXITSTATUS(stat));
+				sprintf(buffer, "exit %d %d\n", cmd.port, WEXITSTATUS(stat));
 				write(cfd, buffer, strlen(buffer));
 			}
 			continue;
@@ -431,6 +439,7 @@ static void initial(int argc, char **argv)
 			plugins.loadExtensions();
 		plugins.loadDebug();
 		plugins.loadDriver();
+		plugins.loadFeeds();
 		plugins.loadModules();
 		plugins.loadDatabase();
 		plugins.loadFunctions();
