@@ -43,6 +43,7 @@ ScriptInterp((aaScript *)driver, keymemory.getSymbolSize(), keymemory.getPageSiz
 	script = NULL;
 	session = NULL;
 	manager = NULL;
+	digits = 0;
 
 	dtmf.bin.id = "digits";
 	dtmf.bin.flags.readonly = false;
@@ -195,6 +196,7 @@ bool Trunk::Attach(const char *name)
 	time_t now;
 	struct tm *dt;
 	struct tm tbuf;
+	char buffer[33];
 
 	// This concerns me.  Why are we returning false?
 	// What, in fact, is this case?
@@ -205,6 +207,10 @@ bool Trunk::Attach(const char *name)
 
 	//Matt B
 
+
+	getName(buffer);
+	slog(SLOG_DEBUG) << buffer << ": low water mark at attach; " << getPages() << endl;
+
 	if(flags.trunk != TRUNK_MODE_OUTGOING) 
 	{
 	    if(flags.script)
@@ -289,6 +295,8 @@ void Trunk::Detach(void)
 	if(!flags.script)
 		return;
 
+	getName(buffer);
+	slog(SLOG_DEBUG) << buffer << ": hi water mark at detach; " << getPages() << endl;
 	Logout();
 	buffer[0] = 0;
 	while(i < cdrc)
